@@ -13,6 +13,7 @@
 #include "pxr/base/tf/errorMark.h"
 #include "pxr/base/work/api.h"
 #include "pxr/base/work/dispatcher.h"
+#include "pxr/base/work/impl.h"
 
 #include <type_traits>
 #include <utility>
@@ -33,12 +34,6 @@ private:
     Fn _fn;
 };
 
-WORK_API
-WorkDispatcher &Work_GetDetachedDispatcher();
-
-WORK_API
-void Work_EnsureDetachedTaskProgress();
-
 /// Invoke \p fn asynchronously, discard any errors it produces, and provide
 /// no way to wait for it to complete.
 template <class Fn>
@@ -47,8 +42,8 @@ void WorkRunDetachedTask(Fn &&fn)
     using FnType = typename std::remove_reference<Fn>::type;
     Work_DetachedTask<FnType> task(std::forward<Fn>(fn));
     if (WorkHasConcurrency()) {
-        Work_GetDetachedDispatcher().Run(std::move(task));
-        Work_EnsureDetachedTaskProgress();
+        PXR_WORK_IMPL_NAMESPACE_USING_DIRECTIVE;
+        WorkImpl_RunDetachedTask<Work_DetachedTask<FnType>>(std::move(task));
     }
     else {
         task();
