@@ -19,7 +19,6 @@
 #include "pxr/exec/vdf/executionStats.h"
 #include "pxr/exec/vdf/executionTypeRegistry.h"
 #include "pxr/exec/vdf/mask.h"
-#include "pxr/exec/vdf/network.h"
 #include "pxr/exec/vdf/networkUtil.h"
 #include "pxr/exec/vdf/node.h"
 #include "pxr/exec/vdf/output.h"
@@ -30,14 +29,8 @@
 #include "pxr/exec/vdf/vector.h"
 
 #include "pxr/base/tf/bits.h"
-#include "pxr/base/trace/trace.h"
-
 #include "pxr/base/tf/mallocTag.h"
-
-#define _VDF_PBEE_TRACE_ON 0
-#if _VDF_PBEE_TRACE_ON
-#include <iostream>
-#endif
+#include "pxr/base/trace/trace.h"
 
 PXR_NAMESPACE_OPEN_SCOPE
 
@@ -338,7 +331,7 @@ VdfPullBasedExecutorEngine<DataManagerType>::RunSchedule(
     _dataManager->Resize(*schedule.GetNetwork());
 
     // Indicates which nodes have been executed.
-    TfBits executedNodes(schedule.GetNetwork()->GetNodeCapacity());
+    TfBits executedNodes(schedule.GetScheduleNodeVector().size());
 
     // The persistent evaluation state
     VdfEvaluationState state(_GetExecutor(), schedule, errorLogger);
@@ -701,9 +694,8 @@ VdfPullBasedExecutorEngine<DataManagerType>::_ExecuteOutput(
     const VdfOutput &output, 
     TfBits *executedNodes)
 {
-#if _VDF_PBEE_TRACE_ON
-    std::cout << "----------------- _ExecuteOutput --------- " << std::endl;
-#endif
+    TF_DEBUG(VDF_PBEE_TRACE).Msg(
+        "----------------- _ExecuteOutput --------- \n");
 
     // The current schedule
     const VdfSchedule &schedule = state.GetSchedule();
@@ -747,10 +739,8 @@ VdfPullBasedExecutorEngine<DataManagerType>::_ExecuteOutput(
 
         case ExecutionStageStart:
 
-#if _VDF_PBEE_TRACE_ON
-            std::cout << "{ BeginNode(\"" 
-                      << node.GetDebugName() << "\");" << std::endl;
-#endif
+            TF_DEBUG(VDF_PBEE_TRACE)
+                .Msg("{ BeginNode(\"%s\");\n", node.GetDebugName().c_str());
 
             // We have to compute if 
             //   o The node has not been executed, yet
@@ -760,15 +750,13 @@ VdfPullBasedExecutorEngine<DataManagerType>::_ExecuteOutput(
             //     schedule.
             output = schedule.GetOutput(outputId);
             requestMask = &schedule.GetRequestMask(outputId);
-            if (executedNodes->IsSet(VdfNode::GetIndexFromId(node.GetId())) ||
+            if (executedNodes->IsSet(schedule.GetScheduleNodeIndex(outputId)) ||
                 _GetExecutor().GetOutputValue(*output, *requestMask)) {
 
                 // Pop off the top of the output stack
                 outputsStack.pop_back();
 
-#if _VDF_PBEE_TRACE_ON
-                std::cout << " EndNodeFoundCache(); }" << std::endl;
-#endif
+                TF_DEBUG(VDF_PBEE_TRACE).Msg(" EndNodeFoundCache(); }\n");
                 continue;
             }
 
@@ -887,27 +875,24 @@ VdfPullBasedExecutorEngine<DataManagerType>::_ExecuteOutput(
         default:
 
             // Set a bit indicating that this node has been executed.
-            executedNodes->Set(VdfNode::GetIndexFromId(node.GetId()));
+            executedNodes->Set(schedule.GetScheduleNodeIndex(outputId));
 
             // Compute the node.
             if (affective) {
                 _ComputeNode(state, node, absorbLockedCache);
-#if _VDF_PBEE_TRACE_ON
-            std::cout << "ComputedNode(\"" 
-                      << node.GetDebugName() 
-                      << "\"); }" << std::endl;
-#endif
+
+                TF_DEBUG(VDF_PBEE_TRACE).Msg(
+                    "ComputedNode(\"%s\"); }\n", node.GetDebugName().c_str());
 
             } else {
                 // The node doesn't have any outputs that need to be computed.
                 // Skip the node passing through the data for read/write
                 // outputs.
                 _PassThroughNode(schedule, node, absorbLockedCache);
-#if _VDF_PBEE_TRACE_ON
-                std::cout << "ComputedNodeInaffective(\"" 
-                          << node.GetDebugName() 
-                          << "\"); }" << std::endl;
-#endif
+
+                TF_DEBUG(VDF_PBEE_TRACE)
+                    .Msg("ComputedNodeInaffective(\"%s\"); }\n",
+                         node.GetDebugName().c_str());
             }
 
             // Pop the output off the stack, once we are done with it
