@@ -9,6 +9,8 @@
 
 #include "pxr/imaging/geomUtil/api.h"
 
+#include "pxr/base/arch/math.h"
+#include "pxr/base/gf/math.h"
 #include "pxr/base/gf/matrix4d.h"
 #include "pxr/base/gf/vec3d.h"
 #include "pxr/base/gf/vec3f.h"
@@ -89,12 +91,13 @@ protected:
     {};
 
     // Helper struct to provide iterator type erasure, allowing subclasses to
-    // implement their GeneratePoints methods privately.  Usage doesn't require
-    // any heap allocation or virtual dispatch/runtime typing.  In addition to
-    // erasing the iterator type, this also provides a convenient way to allow
-    // subclasses to offer GeneratePoints methods that can apply an additional
-    // frame transform without having to actually plumb that detail into the
-    // guts of their point generator code.
+    // implement their GeneratePoints and GenerateNormals methods privately.
+    //  Usage doesn't require any heap allocation or virtual dispatch/runtime
+    // typing.  In addition to erasing the iterator type, this also provides a
+    // convenient way to allow subclasses to offer GeneratePoints and
+    // GenerateNormals methods that can apply an additional frame transform
+    // without having to actually plumb that detail into the guts of their point
+    // generator code.
     //
     // Note: Ensuring the interoperability of the PointType with the IterType
     // used at construction is the responsibility of the client.  It's typically
@@ -108,6 +111,7 @@ protected:
         _PointWriter(
             IterType& iter)
             : _writeFnPtr(&_PointWriter<PointType>::_WritePoint<IterType>)
+            , _writeDirFnPtr(&_PointWriter<PointType>::_WriteDir<IterType>)
             , _untypedIterPtr(static_cast<void*>(&iter))
         {}
 
@@ -117,6 +121,8 @@ protected:
             const GfMatrix4d* const framePtr)
             : _writeFnPtr(
                 &_PointWriter<PointType>::_TransformAndWritePoint<IterType>)
+            , _writeDirFnPtr(
+                &_PointWriter<PointType>::_TransformAndWriteDir<IterType>)
             , _untypedIterPtr(static_cast<void*>(&iter))
             , _framePtr(framePtr)
         {}
@@ -127,6 +133,34 @@ protected:
             (this->*_writeFnPtr)(pt);
         }
 
+        void WriteArc(
+            const typename PointType::ScalarType scaleXY,
+            const std::vector<std::array<
+                typename PointType::ScalarType, 2>>& arcXY,
+            const typename PointType::ScalarType arcZ) const
+        {
+            for (const auto& xy : arcXY) {
+                Write(PointType(scaleXY * xy[0], scaleXY * xy[1], arcZ));
+            }
+        }
+
+        void WriteDir(
+            const PointType& dir) const
+        {
+            (this->*_writeDirFnPtr)(dir);
+        }
+
+        void WriteArcDir(
+            const typename PointType::ScalarType scaleXY,
+            const std::vector<std::array<
+                typename PointType::ScalarType, 2>>& arcXY,
+            const typename PointType::ScalarType arcZ) const
+        {
+            for (const auto& xy : arcXY) {
+                WriteDir(PointType(scaleXY * xy[0], scaleXY * xy[1], arcZ));
+            }
+        }
+
     private:
         template<class IterType>
         void _WritePoint(
@@ -142,13 +176,34 @@ protected:
             const PointType& pt) const
         {
             IterType& iter = *static_cast<IterType*>(_untypedIterPtr);
-            *iter = _framePtr->Transform(pt);
+            using OutType = typename std::remove_reference_t<decltype(*iter)>;
+            *iter = static_cast<OutType>(_framePtr->Transform(pt));
+            ++iter;
+        }
+
+        template<class IterType>
+        void _WriteDir(
+            const PointType& pt) const
+        {
+            IterType& iter = *static_cast<IterType*>(_untypedIterPtr);
+            *iter = pt;
+            ++iter;
+        }
+
+        template<class IterType>
+        void _TransformAndWriteDir(
+            const PointType& dir) const
+        {
+            IterType& iter = *static_cast<IterType*>(_untypedIterPtr);
+            using OutType = typename std::remove_reference_t<decltype(*iter)>;
+            *iter = static_cast<OutType>(_framePtr->TransformDir(dir));
             ++iter;
         }
 
         using _WriteFnPtr =
             void (_PointWriter<PointType>::*)(const PointType &) const;
         _WriteFnPtr _writeFnPtr;
+        _WriteFnPtr _writeDirFnPtr;
         void* _untypedIterPtr;
         const GfMatrix4d* _framePtr;
     };
@@ -202,6 +257,42 @@ protected:
         const size_t numRadial,
         const bool closedSweep);
 
+    // Subclasses that use the topology helper method above must generate points
+    // forming circular arcs and this method will compute the total number of
+    // points required for the topology generated using these same parameters.
+    static size_t _ComputeNumCappedQuadTopologyPoints(
+        const size_t numRadial,
+        const size_t numQuadStrips,
+        const _CapStyle bottomCapStyle,
+        const _CapStyle topCapStyle,
+        const bool closedSweep);
+
+    // Subclasses can use this helper method to generate a unit circular arc
+    // in the XY plane that can then be passed into _PointWriter::WriteArc to
+    // write out the points of circular arcs using varying radii.
+    template<typename ScalarType>
+    static std::vector<std::array<ScalarType, 2>> _GenerateUnitArcXY(
+        const size_t numRadial,
+        const ScalarType sweepDegrees)
+    {
+        constexpr ScalarType twoPi = 2.0 * M_PI;
+        const ScalarType sweepRadians = GfDegreesToRadians(sweepDegrees);
+        const ScalarType sweep = GfClamp(sweepRadians, -twoPi, twoPi);
+        const bool closedSweep = GfIsClose(GfAbs(sweep), twoPi, 1e-6);
+        const size_t numPts = _ComputeNumRadialPoints(numRadial, closedSweep);
+
+        // Construct a circular arc of unit radius in the XY plane.
+        std::vector<std::array<ScalarType, 2>> result(numPts);
+        for (size_t radIdx = 0; radIdx < numPts; ++radIdx) {
+            // Longitude range: [0, sweep]
+            const ScalarType longAngle =
+                (ScalarType(radIdx) / ScalarType(numRadial)) * sweep;
+            result[radIdx][0] = cos(longAngle);
+            result[radIdx][1] = sin(longAngle);
+        }
+        return result;
+    }
+
 public:
 
     // This template provides a "fallback" for GeneratePoints(...) calls that
@@ -222,6 +313,24 @@ public:
             "objects.");
     }
 
+    // This template provides a "fallback" for GenerateNormals(...) calls that
+    // do not meet the SFINAE requirement that the given point-container-
+    // iterator must dereference to a GfVec3f or GfVec3d.  This version
+    // generates a helpful compile time assertion in such a scenario.  As noted
+    // earlier, subclasses should explicitly add a "using" statement with
+    // this method to include it in overload resolution.
+    //
+    template<typename PointIterType,
+             typename Enabled =
+                typename _EnableIfNotGfVec3Iterator<PointIterType>::type>
+    static void GenerateNormals(
+        PointIterType iter, ...)
+    {
+        static_assert(_IsGfVec3Iterator<PointIterType>::value,
+            "This function only supports iterators to GfVec3f or GfVec3d "
+            "objects.");
+    }
+
 };
 
 
