@@ -72,6 +72,10 @@ public:
     void Execute(HdRenderIndex * index,
                  const SdfPathVector &taskPaths);
 
+    HD_API
+    bool AreTasksConverged(HdRenderIndex * index,
+                           const SdfPathVector &taskPaths);
+
 private:
     /// Context containing token-value pairs, that is passed to each
     /// task in the render graph.  The task-context can be pre-populated
