@@ -12,13 +12,8 @@
 #include "pxr/imaging/hd/meshUtil.h"
 #include "pxr/base/vt/types.h"
 
-#if defined(EMBREE_MAJOR_VERSION) && EMBREE_MAJOR_VERSION >= 4
-    #include <embree4/rtcore.h>
-    #include <embree4/rtcore_geometry.h>
-#else
-    #include <embree4/rtcore.h>
-    #include <embree4/rtcore_geometry.h>
-#endif // defined(EMBREE_MAJOR_VERSION) && EMBREE_MAJOR_VERSION >= 4
+#include <embree4/rtcore.h>
+#include <embree4/rtcore_geometry.h>
 
 #include <bitset>
 
