@@ -33,7 +33,9 @@ TF_DEBUG_CODES(
     HDST_LOG_DRAWING_SHADER_PROGRAM_MISSES,
     HDST_LOG_SKIPPED_PRIMVAR,
     HDST_MATERIAL_ADDED,
-    HDST_MATERIAL_REMOVED
+    HDST_MATERIAL_REMOVED,
+    HDST_MTLX,
+    HDST_MTLX_DUMP_SHADER_SOURCEFILE
 );
 
 
