@@ -11,6 +11,7 @@
 #include "pxr/imaging/hdSt/api.h"
 #include "pxr/imaging/hdSt/computation.h"
 
+#include "pxr/base/gf/vec3i.h"
 #include "pxr/base/tf/token.h"
 
 PXR_NAMESPACE_OPEN_SCOPE
@@ -18,18 +19,15 @@ PXR_NAMESPACE_OPEN_SCOPE
 /// Dome Light texture computations GPU
 ///
 ///
-using HdSt_DomeLightComputationGPUSharedPtr =
-    std::shared_ptr<class HdSt_DomeLightComputationGPU>;
+
 using HdStSimpleLightingShaderPtr =
     std::weak_ptr<class HdStSimpleLightingShader>;
 
 ////
 //// \class HdSt_DomeLightComputationGPU
 ///
-/// Given an OpenGL texture at construction time, create a new OpenGL
-/// texture (computed from the contents of the given texture) and sets
-/// the GL name on the given lighting shader during Execute (also
-/// freeing previous texture).
+/// Given a source texture at construction time, create a new texture from
+/// its contents with the provided name using the corresponding shader source.
 ///
 /// If the texture to be created has several mip levels, the texture
 /// will only be created by the computation with level = 0 and the
@@ -41,15 +39,18 @@ public:
     /// Constructor
     HDST_API
     HdSt_DomeLightComputationGPU(
-        // Name of computation shader to use, also used as
-        // key when setting the GL name on the lighting shader
-        const TfToken & shaderToken, 
-        // Lighting shader that remembers the GL texture names
+        // Name of computation shader to use, also used as texture name.
+        const TfToken & shaderToken,
+        // Whether to use the dome light cubemap texture or the dome light
+        // latlong texture as the input for the computation.
+        bool useCubemapAsSourceTexture,
+        // Lighting shader for accessing any referenced textures.
         HdStSimpleLightingShaderPtr const &lightingShader,
         // Number of mip levels.
         unsigned int numLevels = 1,
-        // Level to be filled (0 means also to allocate texture)
-        unsigned int level = 0, 
+        // Level to be filled (0 means also to allocate texture).
+        unsigned int level = 0,
+        // Roughness associated with the texture level.
         float roughness = -1.0);
 
     HDST_API
@@ -66,12 +67,44 @@ public:
 
 private:
     const TfToken _shaderToken;
-    HdStSimpleLightingShaderPtr const _lightingShader;
+    const bool _useCubemapAsSourceTexture;
+    const HdStSimpleLightingShaderPtr _lightingShader;
     const unsigned int _numLevels;
     const unsigned int _level;
     const float _roughness;
 };
 
+////
+//// \class HdSt_DomeLightMipmapComputationGPU
+///
+/// Generate mipmaps for the provided dome light cubemap texture.
+///
+class HdSt_DomeLightMipmapComputationGPU : public HdStComputation
+{
+public:
+    HDST_API
+    HdSt_DomeLightMipmapComputationGPU(
+        // Lighting shader for accessing textures.
+        HdStSimpleLightingShaderPtr const &lightingShader);
+
+    HDST_API
+    void GetBufferSpecs(HdBufferSpecVector *specs) const override {}
+   
+    HDST_API
+    void Execute(HdBufferArrayRangeSharedPtr const &range,
+                 HdResourceRegistry *resourceRegistry) override;
+
+    int GetNumOutputElements() const override { return 0; }
+
+private:
+    const HdStSimpleLightingShaderPtr _lightingShader;
+};
+
+/// Given the dimensions of a 2D dome light texture, compute the resulting
+/// dimensions of the cubemap.
+HDST_API
+GfVec3i HdSt_ComputeDomeLightCubemapDimensions(
+    const GfVec3i& srcDim);
 
 PXR_NAMESPACE_CLOSE_SCOPE
 
