@@ -1,25 +1,8 @@
 //
 // Copyright 2021 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef HDX_SKYDOME_TASK_H
 #define HDX_SKYDOME_TASK_H
@@ -51,6 +34,8 @@ PXR_NAMESPACE_OPEN_SCOPE
 class HdxSkydomeTask : public HdxTask
 {
 public:
+    using TaskParams = HdxRenderTaskParams;
+    
     HDX_API
     HdxSkydomeTask(HdSceneDelegate* delegate, SdfPath const& id);
 
@@ -76,6 +61,7 @@ protected:
 private:
     HdRenderIndex* _renderIndex;
     HgiTextureHandle _skydomeTexture;
+    HgiSamplerHandle _skydomeSampler;
     // Optional internal render setup task, for params unpacking.
     // This is used for aov bindings, camera matrices and framing
     HdxRenderSetupTaskSharedPtr _setupTask;
@@ -113,4 +99,4 @@ private:
 
 PXR_NAMESPACE_CLOSE_SCOPE
 
-#endif
\ No newline at end of file
+#endif
