@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_IMAGING_USD_IMAGING_PRIM_ADAPTER_H
 #define PXR_USD_IMAGING_USD_IMAGING_PRIM_ADAPTER_H
@@ -36,6 +19,7 @@
 
 #include "pxr/imaging/hd/changeTracker.h"
 #include "pxr/imaging/hd/selection.h"
+#include "pxr/usd/sdf/path.h"
 #include "pxr/usd/usd/attribute.h"
 #include "pxr/usd/usd/prim.h"
 #include "pxr/usd/usd/timeCode.h"
@@ -66,15 +50,11 @@ using UsdImagingPrimAdapterSharedPtr =
 /// Base class for all PrimAdapters.
 ///
 class UsdImagingPrimAdapter 
-            : public std::enable_shared_from_this<UsdImagingPrimAdapter>
+  : public std::enable_shared_from_this<UsdImagingPrimAdapter>
 {
 public:
-    
-    UsdImagingPrimAdapter()
-    {}
-
     USDIMAGING_API
-    virtual ~UsdImagingPrimAdapter();
+    virtual ~UsdImagingPrimAdapter() = default;
 
     // ---------------------------------------------------------------------- //
     /// \name Scene Index Support
@@ -497,7 +477,7 @@ public:
     void SetDelegate(UsdImagingDelegate* delegate);
 
     USDIMAGING_API
-    bool IsChildPath(SdfPath const& path) const;
+    virtual bool IsChildPath(const SdfPath& path) const;
     
     /// Returns true if the given prim is visible, taking into account inherited
     /// visibility values. Inherited values are strongest, Usd has no notion of
@@ -685,11 +665,11 @@ public:
     // ---------------------------------------------------------------------- //
 
     /// Returns true if the adapter can be populated into the target index.
-    virtual bool IsSupported(UsdImagingIndexProxy const* index) const {
+    virtual bool IsSupported(UsdImagingIndexProxy const* index) const
+    {
         return true;
     }
 
-
     // ---------------------------------------------------------------------- //
     /// \name Utilties
     // ---------------------------------------------------------------------- //
@@ -701,6 +681,20 @@ public:
             TfToken const& paramName);
 
 protected:
+    friend class UsdImagingInstanceAdapter;
+    friend class UsdImagingPointInstancerAdapter;
+    // ---------------------------------------------------------------------- //
+    /// \name Utility
+    // ---------------------------------------------------------------------- //
+    
+    // Given the USD path for a prim of this adapter's type, returns
+    // the prim's Hydra cache path.
+    USDIMAGING_API
+    virtual SdfPath
+    ResolveCachePath(
+        const SdfPath& usdPath,
+        const UsdImagingInstancerContext* instancerContext = nullptr) const;
+
     using Keys = UsdImagingPrimvarDescCache::Key;
 
     template <typename T>
@@ -720,9 +714,11 @@ protected:
     USDIMAGING_API
     UsdImagingPrimvarDescCache* _GetPrimvarDescCache() const;
 
+    USDIMAGING_API
     UsdImaging_NonlinearSampleCountCache*
         _GetNonlinearSampleCountCache() const;
 
+    USDIMAGING_API
     UsdImaging_BlurScaleCache*
         _GetBlurScaleCache() const;
 
@@ -943,7 +939,6 @@ public:
     }
 };
 
-
 PXR_NAMESPACE_CLOSE_SCOPE
 
 #endif // PXR_USD_IMAGING_USD_IMAGING_PRIM_ADAPTER_H
