@@ -15,7 +15,7 @@
 #   define USDUTILSVALIDATORS_API_TEMPLATE_STRUCT(...)
 #   define USDUTILSVALIDATORS_API_LOCAL
 #else
-#   if defined(USDUTILSVALIDATORS_API_EXPORTS)
+#   if defined(USDUTILSVALIDATORS_EXPORTS)
 #       define USDUTILSVALIDATORS_API ARCH_EXPORT
 #       define USDUTILSVALIDATORS_API_TEMPLATE_CLASS(...)                     \
            ARCH_EXPORT_TEMPLATE(class, __VA_ARGS__)
