@@ -165,7 +165,6 @@ class ViewSettingsDataModel(StateSource, QtCore.QObject):
         self._displayGuide = self.stateProperty("displayGuide", default=False)
         self._displayProxy = self.stateProperty("displayProxy", default=True)
         self._displayRender = self.stateProperty("displayRender", default=False)
-        self._displayPrimId = self.stateProperty("displayPrimId", default=False)
         self._enableSceneMaterials = self.stateProperty("enableSceneMaterials", default=True)
         self._enableSceneLights = self.stateProperty("enableSceneLights", default=True)
         self._cullBackfaces = self.stateProperty("cullBackfaces", default=False)
@@ -238,7 +237,6 @@ class ViewSettingsDataModel(StateSource, QtCore.QObject):
         state["displayGuide"] = self._displayGuide
         state["displayProxy"] = self._displayProxy
         state["displayRender"] = self._displayRender
-        state["displayPrimId"] = self._displayPrimId
         state["enableSceneMaterials"] = self._enableSceneMaterials
         state["enableSceneLights"] = self._enableSceneLights
         state["cullBackfaces"] = self._cullBackfaces
@@ -552,15 +550,6 @@ class ViewSettingsDataModel(StateSource, QtCore.QObject):
     def displayCameraOracles(self, value):
         self._displayCameraOracles = value
 
-    @property
-    def displayPrimId(self):
-        return self._displayPrimId
-
-    @displayPrimId.setter
-    @visibleViewSetting
-    def displayPrimId(self, value):
-        self._displayPrimId = value
-
     @property
     def enableSceneMaterials(self):
         return self._enableSceneMaterials
